library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity ASB004_02 is
	Port ( CLK18M : in std_logic;
			 DSW   : in std_logic;
			 RXF_N : in  std_logic;
			 TXE_N : in  std_logic;
			 RD_N  : out std_logic;
			 WR    : out std_logic;
			 USB_DATA : inout std_logic_vector( 7 downto 0 );

			 I_PORT : in std_logic_vector( 7 downto 0 );
			 O_PORT :out std_logic_vector( 7 downto 0 ));
end ASB004_02;

architecture RTL of ASB004_02 is

component USB_ARBITER is
	Port ( CLK : in  std_logic;
			 RST : in  std_logic;

			 RXF_N : in std_logic;
			 TXE_N : in std_logic;
			 RD_N  : out std_logic;
			 WR    : out std_logic;

			 BUS_BUSY : out std_logic;
			 TG_READY : in  std_logic;

			 USB_DATA  : inout  std_logic_vector( 7 downto 0 );

			 TG_DO : out std_logic_vector( 7 downto 0 );
			 TG_DI : in  std_logic_vector( 7 downto 0 );

			 TG_RD : out std_logic;
			 TG_WR : in  std_logic );
end component;	

	signal RST   : std_logic;
	signal TG_DI : std_logic_vector( 7 downto 0 );	
	signal TG_DO : std_logic_vector( 7 downto 0 );	
	signal ENB   : std_logic;
	signal READY : std_logic;
	signal BUSY  : std_logic;

begin


	RST <= not DSW;

	O_PORT <= not TG_DO;
	TG_DI  <= not I_PORT;

	READY  <= not BUSY;

	U0 : USB_ARBITER port map 
		  ( CLK => CLK18M,
			 RST => RST,

			 RXF_N => RXF_N, -- IN
			 TXE_N => TXE_N, -- IN
			 RD_N  => RD_N,  -- OUT
			 WR    => WR,    -- OUT

			 BUS_BUSY => BUSY,   -- OUT
			 TG_READY => READY,  -- IN

			 USB_DATA => USB_DATA, 

			 TG_DO    => TG_DO,
			 TG_DI    => TG_DI,

			 TG_RD    => ENB,
			 TG_WR    => ENB );

end RTL;



